//-*-c++-*-
/**
 Author: David Auber
 Email : auber@labri.fr
 Last modification : 20/08/2001
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by  
 the Free Software Foundation; either version 2 of the License, or     
 (at your option) any later version.
*/

#ifndef _ConnectedAndTreeComponent_H
#define _ConnectedAndTreeComponent_H
#include <stack>
#include <tulip/TulipPlugin.h>

/** \addtogroup metric */
/*@{*/
class ConnectedAndTreeComponent:public Metric { 
public:
  ConnectedAndTreeComponent(const PropertyContext &);
  ~ConnectedAndTreeComponent();
  bool run();
private:
  int  attachNumerotation(node, stdext::hash_map<node,bool> &, stdext::hash_map<node,bool> &,
			  stdext::hash_map<node,int> &, int &, std::stack<node> &, int &);
  void treeRenum(node, std::map<int,int> &);
};
/*@}*/
#endif











